#include "fileio.ch"
#include "openmode.ch"
/* File.....: openmode.prg
 * Author...: Victor Szol, tidied up by Peter Townsend
 * CIS ID...:
 * e-mail...: vector@mail.matav.hu      cephas@tpgi.com.au
 *
 * NB: Can't tell the difference between USE EXCLUSIVE and FLOCK().
 *
 */
/*  $DOC$
 *  $FUNCNAME$
 *      OpenMode()
 *
 *  $ONELINER$
 *      Return the shared status of a file.
 *
 *  $SYNTAX$
 *      OpenMode( [<cFileName>] ) -> nOpenMode
 *
 *  $ARGUMENTS$
 *      cFileName  - name of file to be checked.
 *                   (Default extension for cFileName is ".DBF")
 *
 *  $RETURNS$
 *      nOpenMode  - current mode of use of file
 *                   (0 = not open, 1 = open shared, 2 = open exclusive)
 *
 *  $DESCRIPTION$
 *      This function returns the status of a file with regard to its
 *      being closed, opened (shared), or opened (exclusive).
 *
 *  $EXAMPLES$
 *      IF OpenMode("accounts") == OM_EXCLUSIVE
 *         ? "Cannot open file for sharing - currently opened exclusive"
 *      ELSE
 *         DBUSEAREA(.T., , "accounts", "accounts", .F.)
 *      ENDIF
 *
 *  $SEEALSO$
 *
 *  $INCLUDE$
 *      fileio.ch
 *      openmode.ch
 *
 *  $END$
 */
FUNCTION OpenMode(cFileName)
    LOCAL hFile, nRetVal
    IF ! ("." $ cFileName)
        cFileName += ".DBF"
    ENDIF
    nRetVal := OM_EXCLUSIVE
    *
    IF !FILE(cFileName)
        nRetVal := OM_CLOSED
    ELSE
        hFile := FOPEN(cFileName, FO_READ + FO_EXCLUSIVE)
        IF hFile != F_ERROR
            FCLOSE(hFile)
            nRetVal := OM_CLOSED
        ELSE
            hFile := FOPEN(cFileName, FO_READ + FO_SHARED)
            IF hFile != F_ERROR
                FCLOSE(hFile)
                nRetVal := OM_SHARED
            ENDIF
        ENDIF
    ENDIF
RETURN(nRetVal)
